-------- IDOK_PLIKI
create table IDOK_PLIKI
(
  kod                        NUMBER(15) not null,
  nazwa                      varchar2(100),
  url                        VARCHAR2(300),
  opis                       VARCHAR2(1000),
  data_imp                   date default sysdate not null,
  status                     NUMBER(1) default 0 not null
);

alter table IDOK_pliki
  add constraint IDOK_pliki_PK primary key (KOD)
  using index;

comment on column IDOK_PLIKI.STATUS
  is '0 - podczas przetwarzania, 1- przetwarzanie poprawnie zakoczone, -1 - przetwarzanie zakoczone z bedami';


create sequence seq_IDOK_pliki_KOD
minvalue 1
maxvalue 999999999999
start with 1
increment by 1
nocache
cycle;

create or replace trigger idok_pliki_init BEFORE INSERT ON idok_pliki REFERENCING NEW AS new OLD AS old FOR EACH ROW
declare v_tmp_nr integer;
BEGIN
  if (:new.kod is null) then
    select seq_IDOK_pliki_KOD.nextval into :new.kod from dual;
  end if;
END;
/

-------- IDOK_ZAM
create table IDOK_ZAM
(
  idok_pliki_kod             NUMBER(15) not null,
  KOD                        NUMBER(15) not null,
  KOD_W_EP                   NUMBER(15),
  KOD_U_ODB                  varchar2(30),
  wart_netto                 NUMBER(15,2) not null,
  wart_brutto                NUMBER(15,2) not null,
  data_zam                   date not null,
  termin_real                date not null,
  sp_plat                    char(1) not null,
  termin_plat                date,
  transport                  char(1) not null,
  komentarz                  varchar2(1000),
  odb_kod_iln                varchar2(13),
  odb_ekod                   number(8),
  odb_fkod                   VARCHAR2(50),
  odb_nip                    varchar2(10),
  odb_nip_plat               varchar2(10),
  odb_nazwa                  varchar2(100),
  odb_adres                  varchar2(300),
  dost_kod_iln               varchar2(13),
  dost_ekod_fr               NUMBER(6),
  dost_frid                  VARCHAR2(15),
  dost_nazwa_fr              VARCHAR2(100),
  dost_ekod_fl               NUMBER(6),
  dost_fkod_fl               VARCHAR2(50),
  dost_nazwa_fl              VARCHAR2(100),
  STATUS                     NUMBER(1) default 0 not null
);

comment on column IDOK_ZAM.STATUS
  is '0 - podczas przetwarzania, 1- przetwarzanie poprawnie zakoczone, -1 - przetwarzanie zakoczone z bedami';

alter table IDOK_zam
  add constraint IDOK_zam_PK primary key (KOD)
  using index;

alter table IDOK_zam
  add constraint IDOK_zam_pliki_FK foreign key (IDOK_pliki_KOD)
  references IDOK_pliki (KOD);

  
create sequence seq_IDOK_zam_KOD
minvalue 1
maxvalue 999999999999
start with 1
increment by 1
nocache
cycle;

create or replace trigger idok_zam_init BEFORE INSERT ON idok_zam REFERENCING NEW AS new OLD AS old FOR EACH ROW
declare v_tmp_nr integer;
BEGIN
  if (:new.kod is null) then
    select seq_IDOK_zam_KOD.nextval into :new.kod from dual;
  end if;
END;
/

-------- IDOK_POZ_ZAM
create table IDOK_ZAM_POZ
(
  idok_zam_KOD               NUMBER(15) not null,
  lp                         NUMBER(5) not null,
  indeks_dost                varchar2(30) not null,
  kod_ean                    varchar2(13),
  opk_zb                     NUMBER(10,3) not null,
  il_jedn_zam                NUMBER(10,3) not null,
  jm                         varchar2(5),
  cena_netto                 NUMBER(9,2) not null,
  stawka_vat                 CHAR(1),
  proc_vat                   NUMBER(5,2),
  proc_boni                  NUMBER(5,2),
  odb_data_waz               date,
  opis                       varchar2(100)
);

alter table IDOK_ZAM_POZ
  add constraint IDOK_zam_Poz_PK primary key (idok_zam_KOD,lp)
  using index;

alter table IDOK_zam_poz
  add constraint IDOK_zam_poz_FK foreign key (IDOK_zam_KOD)
  references IDOK_zam (KOD);


create table IDOK_LOG
(
  DATA            DATE default sysdate not null,
  TYP             VARCHAR2(10) default 'INFO' not null,
  MODUL           VARCHAR2(30),
  TEKST           VARCHAR2(4000),
  IDOK_PLIKI_KOD  NUMBER(15),
  IDOK_ZAM_KOD    NUMBER(15),
  IDOK_ZAM_POZ_LP NUMBER(5),
  S_USERNAME      VARCHAR2(30),
  S_OSUSER        VARCHAR2(30),
  S_MACHINE       VARCHAR2(64),
  S_TERMINAL      VARCHAR2(16),
  S_PROGRAM       VARCHAR2(64)
);

